| allot_units | R Documentation |
This function adds the edges between factor nodes to describe the high-level relationship between factors. This function does not actually assign edges between level nodes.
allot_units(.edibble, ..., .record = TRUE)
.edibble |
An edibble design which should have units, treatments and allotment defined. |
... |
A two-sided formula. |
.record |
Whether to record the step. |
Return an edibble design.
assign_fcts
Other user-facing functions:
allot_trts(),
design(),
expect_rcrds(),
export_design(),
serve_table(),
set_rcrds(),
set_trts(),
set_units()
design() %>%
set_units(block = 10,
plot = 20) %>%
allot_units(block ~ plot)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.