| expect_rcrds | R Documentation |
Set the expected values for recording variables
expect_rcrds(.edibble = NULL, ..., .record = TRUE)
.edibble |
An edibble design ( |
... |
Name-value pairs with the name belonging to the variable
that are plan to be recorded from |
.record |
A logical value. This indicates whether to record this code step. The default is TRUE. It should remain TRUE unless this function is used as a wrapper in other code. |
An edibble design.
Other user-facing functions:
allot_trts(),
allot_units(),
design(),
export_design(),
serve_table(),
set_rcrds(),
set_trts(),
set_units()
takeout(menu_crd(t = 4, n = 10)) %>%
set_rcrds(y = unit) %>%
expect_rcrds(y > 0)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.