is_provenance: Check if an object is an instance of the "Provenance" class.

View source: R/provenance.R

is_provenanceR Documentation

Check if an object is an instance of the "Provenance" class.

Description

This function determines whether the given object is an instance of the "Provenance" class.

Usage

is_provenance(x)

Arguments

x

An object to be checked for its class membership.

Value

TRUE if the object is an instance of the "Provenance" class, FALSE otherwise.


emitanaka/edibble documentation built on April 5, 2025, 4:11 a.m.