| menu_bibd | R Documentation |
Some combinations of parameter values cannot create a balanced incomplete block design.
menu_bibd(
t = random_integer_small(min = 3),
k = random_integer_small(max = t - 1),
r = random_integer_small(),
seed = random_seed_number()
)
t |
The number of treatments. |
k |
The size of the block. This should be less than the number of treatments. |
r |
The number of replications for each treatment level. |
seed |
A scalar value for computational reproducibility. |
A recipe for balance incomplete block design.
Other recipe-designs:
menu_crd(),
menu_factorial(),
menu_graeco(),
menu_hyper_graeco(),
menu_lsd(),
menu_rcbd(),
menu_split(),
menu_strip(),
menu_youden()
menu_bibd(t = 3, k = 2, r = 4)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.